@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # coding: utf-8
 
 """
@@ -10,22 +9,24 @@ The main entry point to these classes should be through
 
 import abc
 import logging
-
 import threading
 import time
-
+import warnings
 
 log = logging.getLogger('can.bcm')
 
 
 class CyclicTask(object):
     """
-    Abstract Base for all Cyclic Tasks
+    Abstract Base for all cyclic tasks.
     """
 
     @abc.abstractmethod
     def stop(self):
         """Cancel this periodic task.
+
+        :raises can.CanError:
+            If stop is called on an already stopped task.
         """
 
 
@@ -36,7 +37,7 @@ class CyclicSendTaskABC(CyclicTask):
 
     def __init__(self, message, period):
         """
-        :param message: The :class:`can.Message` to be sent periodically.
+        :param can.Message message: The message to be sent periodically.
         :param float period: The rate in seconds at which to send the message.
         """
         self.message = message
@@ -51,7 +52,7 @@ class LimitedDurationCyclicSendTaskABC(CyclicSendTaskABC):
     def __init__(self, message, period, duration):
         """Message send task with a defined duration and period.
 
-        :param message: The :class:`can.Message` to be sent periodically.
+        :param can.Message message: The message to be sent periodically.
         :param float period: The rate in seconds at which to send the message.
         :param float duration:
             The duration to keep sending this message at given rate.
@@ -76,19 +77,28 @@ class ModifiableCyclicTaskABC(CyclicSendTaskABC):
         """Update the contents of this periodically sent message without altering
         the timing.
 
-        :param message: The :class:`~can.Message` with new :attr:`can.Message.data`.
+        :param can.Message message:
+          The message with the new :attr:`can.Message.data`.
+          Note: The arbitration ID cannot be changed.
         """
         self.message = message
 
 
 class MultiRateCyclicSendTaskABC(CyclicSendTaskABC):
-    """Exposes more of the full power of the TX_SETUP opcode.
-
-    Transmits a message `count` times at `initial_period` then
-    continues to transmit message at `subsequent_period`.
+    """A Cyclic send task that supports switches send frequency after a set time.
     """
 
     def __init__(self, channel, message, count, initial_period, subsequent_period):
+        """
+        Transmits a message `count` times at `initial_period` then continues to
+        transmit message at `subsequent_period`.
+
+        :param channel: See interface specific documentation.
+        :param can.Message message:
+        :param int count:
+        :param float initial_period:
+        :param float subsequent_period:
+        """
         super(MultiRateCyclicSendTaskABC, self).__init__(channel, message, subsequent_period)
 
 
@@ -135,12 +145,14 @@ class ThreadBasedCyclicSendTask(ModifiableCyclicTaskABC,
 
 
 def send_periodic(bus, message, period, *args, **kwargs):
-    """Send a message every `period` seconds on the given channel.
+    """
+    Send a :class:`~can.Message` every `period` seconds on the given bus.
 
-    :param bus: The :class:`can.BusABC` to transmit to.
-    :param message: The :class:`can.Message` instance to periodically send
+    :param can.BusABC bus: A CAN bus which supports sending.
+    :param can.Message message: Message to send periodically.
+    :param float period: The minimum time between sending messages.
     :return: A started task instance
     """
-    log.warning("The function `can.send_periodic` is deprecated and will " +
-             "be removed in version 2.3. Please use `can.Bus.send_periodic` instead.")
+    warnings.warn("The function `can.send_periodic` is deprecated and will " +
+                  "be removed in an upcoming version. Please use `can.Bus.send_periodic` instead.", DeprecationWarning)
     return bus.send_periodic(message, period, *args, **kwargs)
