@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # coding: utf-8
 
 """
@@ -8,22 +7,23 @@ to a CAN bus.
 Similar to canplayer in the can-utils package.
 """
 
-from __future__ import print_function
+from __future__ import absolute_import, print_function
 
+import sys
 import argparse
-import datetime
+from datetime import datetime
 
 import can
-from can.io.player import LogReader, MessageSync
+from can import Bus, LogReader, MessageSync
 
 
 def main():
     parser = argparse.ArgumentParser(
         "python -m can.player",
-        description="Replay CAN traffic")
+        description="Replay CAN traffic.")
 
     parser.add_argument("-f", "--file_name", dest="log_file",
-                        help="""Path and base log filename, extension can be .txt, .asc, .csv, .db, .npz""",
+                        help="""Path and base log filename, for supported types see can.LogReader.""",
                         default=None)
 
     parser.add_argument("-v", action="count", dest="verbosity",
@@ -44,41 +44,56 @@ def main():
                         help='''Bitrate to use for the CAN bus.''')
 
     parser.add_argument('--ignore-timestamps', dest='timestamps',
-                        help='''Ignore timestamps (send all frames immediately with minimum gap between
-    frames)''', action='store_false')
+                        help='''Ignore timestamps (send all frames immediately with minimum gap between frames)''',
+                        action='store_false')
 
-    parser.add_argument('-g', '--gap', type=float, help='''<s> minimum time between replayed frames''')
+    parser.add_argument(
+        "--error-frames",
+        help="Also send error frames to the interface.",
+        action="store_true",
+    )
+
+    parser.add_argument('-g', '--gap', type=float, help='''<s> minimum time between replayed frames''',
+                        default=0.0001)
     parser.add_argument('-s', '--skip', type=float, default=60*60*24,
                         help='''<s> skip gaps greater than 's' seconds''')
 
     parser.add_argument('infile', metavar='input-file', type=str,
-                        help='The file to replay. Supported types: .db, .blf')
+                        help='The file to replay. For supported types see can.LogReader.')
+
+    # print help message when no arguments were given
+    if len(sys.argv) < 2:
+        parser.print_help(sys.stderr)
+        import errno
+        raise SystemExit(errno.EINVAL)
 
     results = parser.parse_args()
 
     verbosity = results.verbosity
-    gap = 0.0001 if results.gap is None else results.gap
 
     logging_level_name = ['critical', 'error', 'warning', 'info', 'debug', 'subdebug'][min(5, verbosity)]
     can.set_logging_level(logging_level_name)
 
+    error_frames = results.error_frames
+
     config = {"single_handle": True}
     if results.interface:
-        config["bustype"] = results.interface
+        config["interface"] = results.interface
     if results.bitrate:
         config["bitrate"] = results.bitrate
-    bus = can.interface.Bus(results.channel, **config)
+    bus = Bus(results.channel, **config)
 
-    player = LogReader(results.infile)
+    reader = LogReader(results.infile)
 
-    in_sync = MessageSync(player, timestamps=results.timestamps,
-                          gap=gap, skip=results.skip)
+    in_sync = MessageSync(reader, timestamps=results.timestamps,
+                          gap=results.gap, skip=results.skip)
 
-    print('Can LogReader (Started on {})'.format(
-        datetime.datetime.now()))
+    print('Can LogReader (Started on {})'.format(datetime.now()))
 
     try:
         for m in in_sync:
+            if m.is_error_frame and not error_frames:
+                continue
             if verbosity >= 3:
                 print(m)
             bus.send(m)
@@ -86,6 +101,7 @@ def main():
         pass
     finally:
         bus.shutdown()
+        reader.stop()
 
 
 if __name__ == "__main__":
